#!/bin/bash
set -e

echo "📦 Wykrywanie systemu i instalacja pakietów..."

if [ -f /etc/debian_version ]; then
    echo "🟢 Debian/Ubuntu"
    sudo apt update
    sudo apt install -y mariadb-server mariadb-client libmariadb-dev \
                        libqt5pas-dev libqt5widgets5 libqt5gui5 libqt5core5a qtbase5-dev \
                        libgtk2.0-dev
elif [ -f /etc/redhat-release ]; then
    echo "🔵 Fedora/RedHat/CentOS"
    sudo dnf install -y mariadb-server mariadb mariadb-devel \
                        qt5-qtbase-devel qt5pas gtk2-devel || \
    sudo yum install -y mariadb-server mariadb mariadb-devel qt5-qtbase-devel qt5pas gtk2-devel
elif grep -qi suse /etc/os-release; then
    echo "🟣 openSUSE"
    sudo zypper install -y mariadb mariadb-client libmariadb-devel \
                          libqt5-qtbase-devel libQt5Pas1 gtk2-devel
else
    echo "❌ Nieobsługiwany system. Przerwano."
    exit 1
fi

echo "🚀 Uruchamianie i zabezpieczanie serwera..."
sudo systemctl enable mariadb
sudo systemctl start mariadb

echo "🧑‍💻 Tworzenie użytkownika i bazy danych..."

sudo mysql <<EOF
CREATE USER IF NOT EXISTS 'ndg'@'localhost' IDENTIFIED BY 'Variable';
CREATE DATABASE IF NOT EXISTS ndg DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
GRANT ALL PRIVILEGES ON ndg.* TO 'ndg'@'localhost';
FLUSH PRIVILEGES;
EOF

echo "📥 Importowanie pliku SQL do bazy..."

if [ ! -f ndg.sql ]; then
    echo "❌ Brak pliku ndg.sql w bieżącym katalogu. Przerwano."
    exit 1
fi

mysql -u ndg -pVariable ndg < ndg.sql

echo "📁 Tworzenie katalogu ~/ndg i kopiowanie plików..."

mkdir -p "$HOME/fonts"
mkdir -p "$HOME/ndg/pomoc"
mkdir -p "$HOME/Dokumenty/backup_db"
cp ./undg ./undg.ico ./setup.dat "$HOME/ndg/"
[ -d ./fonts ] && cp -r ./fonts/* "$HOME/fonts/" || echo "⚠️ Brak katalogu fonts – pominięto"

mkdir -p "$HOME/ndg/pomoc"
cp -r ./pomoc/* "$HOME/ndg/pomoc/" || echo "⚠️ Brak katalogu pomoc – pominięto"

echo "🔧 Nadawanie uprawnień do uruchamiania programu..."
chmod +x "$HOME/ndg/undg"

echo "🖼️  Tworzenie skrótu menu w ~/.local/share/applications..."

mkdir -p "$HOME/.local/share/applications"

ICON_PATH="$HOME/ndg/undg.png"
[ ! -f "$ICON_PATH" ] && ICON_PATH="$HOME/ndg/undg.ico"

cat > "$HOME/.local/share/applications/ndg.desktop" <<EOF
[Desktop Entry]
Name=NDG – Faktury
Comment=Program do fakturowania dla NDG
Exec=$HOME/ndg/undg
Icon=$ICON_PATH
Type=Application
Categories=Office;Finance;
StartupNotify=true
Terminal=false
EOF

chmod +x "$HOME/.local/share/applications/ndg.desktop"

echo "✅ Instalacja zakończona. Program dostępny w ~/ndg i menu aplikacji."
